(define-module (skg packages sdl-audiolib)
  #:use-module (guix)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system cmake)
  #:use-module (guix git-download)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (gnu packages)
  #:use-module (gnu packages sdl)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages pulseaudio)
  #:use-module (gnu packages mp3)
  #:use-module (gnu packages audio)
  #:use-module (gnu packages xiph))

(define-public libadlmidi
  (package
    (name "libadlmidi")
    (version "1.5.1")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/Wohlstand/libADLMIDI.git")
              (commit "v1.5.1")))
        (file-name (git-file-name name version))
        (sha256 (base32 "0lk61j72c1qwpq0a68vkpw7qiyv2byv7852iz4mvcivsi9gmlr6l"))))
    (build-system cmake-build-system)
    (arguments (list 
                     #:tests? #f
                     #:build-type "Release"))
    (home-page "https://github.com/Wohlstand/libADLMIDI")
    (synopsis "libADLMIDI is a free Software MIDI synthesizer library with OPL3 emulation")
    (description "A Software MIDI Synthesizer library with OPL3 (YMF262) emulator ")
    (license license:lgpl3)))

(define-public sdl_audiolib
  (package
    (name "sdl_audiolib")
    (version "1")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/realnc/SDL_audiolib.git")
              (commit "b2df2dfeddc692caa01fd1e1769f59b285912b87")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1rgij08si84n927yxvbqlxhbvmph3zjshy3rgjj665m1dnxdayls"))))
    (inputs
     (list libvorbis sdl2 pkg-config libsamplerate libmpcdec libopenmpt wildmidi libadlmidi soxr libopenmpt libxmp libmodplug opusfile fluidsynth))
    (build-system cmake-build-system)
    (arguments '(
                     #:tests? #f
		     #:configure-flags (list "-DUSE_RESAMP_SRC=OFF"
    "-DUSE_RESAMP_SOXR=OFF"
    "-DUSE_DEC_DRFLAC=OFF"
    "-DUSE_DEC_OPENMPT=OFF"
    "-DUSE_DEC_XMP=OFF"
    "-DUSE_DEC_MODPLUG=OFF"
    "-DUSE_DEC_MPG123=OFF"
    "-DUSE_DEC_SNDFILE=OFF"
    "-DUSE_DEC_LIBVORBIS=OFF"
    "-DUSE_DEC_LIBOPUSFILE=OFF"
    "-DUSE_DEC_MUSEPACK=OFF"
    "-DUSE_DEC_FLUIDSYNTH=OFF"
    "-DUSE_DEC_BASSMIDI=OFF"
    "-DUSE_DEC_WILDMIDI=OFF"
    "-DUSE_DEC_ADLMIDI=OFF")
                     #:build-type "Release"))
    (home-page "https://github.com/realnc/SDL_audiolib")
    (synopsis "This is a small and simple to use C++ library for playing various audio formats. It is a thin (-ish) wrapper around existing resampling (like SRC or SoX) and decoding libraries (like libmpg123 or libvorbis.)")
    (description "An audio decoding, resampling and mixing library for SDL. ")
    (license license:gpl3)))

