(define-module (skg packages smpq)
  #:use-module (guix)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system cmake)
  #:use-module (guix git-download)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (gnu packages))

(define-public stormlib
  (package
    (name "stormlib")
    (version "9.25")
    (source
      (origin
        (method git-fetch)
        (uri (git-reference
              (url "https://github.com/ladislav-zezula/StormLib.git")
              (commit "v9.25")))
        (file-name (git-file-name name version))
        (sha256 (base32 "1mqm8n6gkdy2pr4s8a8zqb1n0hhy4qai3msx7xdb82famhabcf0x"))))
    (build-system cmake-build-system)
    (arguments '(
                     #:tests? #f
		     #:configure-flags (list "-DBUILD_SHARED_LIBS=ON") ;;"-DWITH_LIBTOMCRYPT=ON")
                     #:build-type "Release"
		     #:phases
		     (modify-phases %standard-phases
				    (add-after 'unpack 'update-cmake
					       (lambda _
						 (substitute* "CMakeLists.txt"
							      (("FRAMEWORK DESTINATION /Library/Frameworks") "FRAMEWORK DESTINATION Library/Frameworks"))
						 #t)))))
    (home-page "https://github.com/ladislav-zezula/StormLib")
    (synopsis "An open-source project that can work with Blizzard MPQ archives.")
    (description "Work with Blizzard MPQ archives.")
    (license license:expat)))

(define-public smpq
  (package
    (name "smpq")
    (version "1.6")
    (source
      (origin
        (method url-fetch)
        (uri "https://launchpad.net/smpq/trunk/1.6/+download/smpq_1.6.orig.tar.gz")
        (sha256 (base32 "1jqq5x3b17jy66x3kkf5hs5l322dx2v14djxxrqrnqp8bn5drlmm"))))
    (build-system cmake-build-system)
    (inputs (list stormlib))
    (arguments '(
                     #:tests? #f
		     #:configure-flags (list "-DWITH_KDE=OFF" "LDFLAGS=-static")
                     #:build-type "Release"))
    (home-page "https://code.launchpad.net/smpq")
    (synopsis "SMPQ is StormLib MPQ archiving utility. This utility is designed for full manipulating with Blizzard MPQ archives. It supports extracting, appending, renaming and deleting files in MPQ archives. It also can create MPQ archive. SMPQ can access to different type of MPQ archives and version. It support encrypted, compressed, partial and patched MPQ archives with version 1-4. SMPQ is free open source command line utility written in C/C++ which use multiplatform C++ StormLib library.")
    (description "SMPQ is StormLib MPQ archiving utility.")
    (license license:expat)))
;; This allows you to run guix shell -f example.scm.
;; Remove this line if you just want to define a package.
smpq
